@@ -16,7 +16,6 @@ fn impl_checkout_server(ast: &syn::DeriveInput) -> TokenStream {
     let name = &ast.ident;
     let gen = quote! {
         mod checkout_server {
-            pub use checkout_core::{money::Currency, Checkout, Context, ContextProvider, Server, Error};
             pub use checkout_core::dropshot::endpoint;
             pub use checkout_core::dropshot::ApiDescription;
             pub use checkout_core::dropshot::ConfigDropshot;
@@ -28,11 +27,17 @@ fn impl_checkout_server(ast: &syn::DeriveInput) -> TokenStream {
             pub use checkout_core::dropshot::RequestContext;
             pub use checkout_core::dropshot::TypedBody;
             pub use checkout_core::http::StatusCode;
-            pub use checkout_core::serde::{Deserialize, Serialize};
-            pub use std::sync::Arc;
+            pub use checkout_core::{
+                error::Error, money::Currency, Checkout, Context, ContextProvider, Server,
+            };
+
+            use std::sync::Arc;
+            use checkout_core::dropshot as _;
+            use serde::{Deserialize, Serialize};
+            use schemars::JsonSchema;
 
             pub struct ServerContext {
-                context_provider: #name,
+                pub context_provider: #name
             }
 
             #[derive(Serialize, Deserialize, JsonSchema)]
@@ -49,15 +54,20 @@ fn impl_checkout_server(ast: &syn::DeriveInput) -> TokenStream {
                 body_params: TypedBody<CreateRequest>,
             ) -> Result<HttpResponseOk<Checkout>, HttpError> {
                 let params = body_params.into_inner();
-                let mut ctx = req_ctx.context().context_provider.new_context().await.unwrap();
+                let mut ctx = req_ctx
+                    .context()
+                    .context_provider
+                    .new_context()
+                    .await
+                    .unwrap();
 
                 ctx.start_transaction().await.unwrap();
-                match Checkout::create(&mut ctx, params.currency.clone()).await? {
+                match Checkout::create(&mut ctx, params.currency.clone()).await {
                     Ok(co) => {
                         ctx.commit_transaction().await.unwrap();
                         Ok(HttpResponseOk(co))
                     }
-                    Err(err) => {
+                    Err(_) => {
                         ctx.abort_transaction().await.unwrap();
                         Err(HttpError {
                             status_code: StatusCode::BAD_REQUEST,
@@ -73,20 +83,26 @@ fn impl_checkout_server(ast: &syn::DeriveInput) -> TokenStream {
         impl checkout_server::Server for #name {
             type Context = checkout_server::ServerContext;
 
-            fn api_description() -> ApiDescription<checkout_server::ServerContext> {
-                let mut api = checkout_server::ApiDescription<checkout_server::ServerContext>::new();
+            fn api_description() -> checkout_server::ApiDescription<checkout_server::ServerContext> {
+                let mut api = checkout_server::ApiDescription::<checkout_server::ServerContext>::new();
                 api.register(checkout_server::create_handler).unwrap();
                 api
             }
 
-            fn new_server(self, bind_address: &str) -> Result<checkout_server::HttpServerStarter<checkout_server::ServerContext>, checkout_server::Error> {
+            fn new_server(
+                self,
+                bind_address: &str,
+            ) -> Result<
+                checkout_server::HttpServerStarter<checkout_server::ServerContext>,
+                checkout_server::Error,
+            > {
                 let log = checkout_server::ConfigLogging::StderrTerminal {
                     level: checkout_server::ConfigLoggingLevel::Info,
                 }
                 .to_logger("minimal-example")
                 .map_err(|_| checkout_server::Error {
                     code: "500".to_string(),
-                    message: "failed to bind server".to_string()
+                    message: "failed to bind server".to_string(),
                 })?;
 
                 let api = Self::api_description();
@@ -97,14 +113,14 @@ fn impl_checkout_server(ast: &syn::DeriveInput) -> TokenStream {
                         request_body_max_bytes: 2048 * 1024,
                     },
                     api,
-                    *checkout_server::Arc::new(checkout_server::ServerContext {
-                        context_provider: self
-                    }),
+                    checkout_server::ServerContext {
+                        context_provider: self,
+                    },
                     &log,
                 )
                 .map_err(|_| checkout_server::Error {
                     code: "500".to_string(),
-                    message: "failed to bind server".to_string()
+                    message: "failed to bind server".to_string(),
                 })
             }
         }
